Index: trunk/Ohana/src/opihi/pantasks/task.c
===================================================================
--- trunk/Ohana/src/opihi/pantasks/task.c	(revision 4697)
+++ trunk/Ohana/src/opihi/pantasks/task.c	(revision 4705)
@@ -36,11 +36,15 @@
   if (task == NULL) { /**** new task ****/
     task = CreateTask (argv[1]);
+  } else {
+    RemoveTask (task);
+    SetNewTask (task);
   }
-  /* temporary task is saved statically 
-     add to list after definition is complete */
+  /* While a task is being defined, it is removed from the task list.  The new task is added to the task list
+     when the definition process is complete.  
+     XXX If an outstanding job has a task deleted, it will not be able to complete... */
 
   /* read in task from appropriate source (keyboard or list) until end */
 
   /* allowed tokens: command, host, stderr, periods, end */
 
   ThisList = Nlists;
@@ -36,11 +36,15 @@
   /* read in task from appropriate source (keyboard or list) until end */
 
-  /* allowed tokens: command, host, stderr, periods, end */
+  /* allowed tokens: command, host, stderr, periods, trange, nmax, task.exit, task.exec, end */
 
   ThisList = Nlists;
